-- SQL script to create the tables necessary for lab 1 in EDA216.
-- MySQL version.
--
-- Creates the tables Students, Courses, TakenCourses and
-- populates them with (simulated) data.
--
-- We disable foreign key checks temporarily so we can delete the
-- tables in arbitrary order, and so insertion is faster.

PRAGMA foreign_keys = OFF;

-- Drop the tables if they already exist.

drop table if exists Students;
drop table if exists Courses;
drop table if exists TakenCourses;

-- Create the tables. The 'check' constraints are not effective in MySQL. 

create table Students (
    pNbr        char(11),
    firstName   varchar(20) not null,
    lastName    varchar(20) not null,
    primary key (pNbr)
);

create table Courses (
    courseCode  char(6),
    courseName  varchar(50) not null,
    credits     integer not null check (credits > 0),
    primary key (courseCode)
);

create table TakenCourses (
    pNbr        char(11),
    courseCode  char(6),
    grade       integer not null check (grade >= 3 and grade <= 5),
    primary key (pNbr, courseCode),
    foreign key (pNbr) references Students(pNbr),
    foreign key (courseCode) references Courses(courseCode)
);

-- We will do a lot of inserts, so we start a transaction to make it faster.

begin transaction;

-- Populate the Students table.

insert into Students values 
('710721-1927','Anna','Johansson'),
('700627-2889','Anna','Johansson'),
('730817-3900','Eva','Alm'),
('760213-3782','Eva','Nilsson'),
('780908-3285','Elaine','Robertson'),
('780211-2743','Maria','Nordman'),
('731108-2767','Helena','Troberg'),
('770806-2406','Lotta','Emanuelsson'),
('701017-3008','Anna','Nyström'),
('710622-2123','Maria','Andersson'),
('730411-3207','Marie','Persson'),
('780404-2286','Märit','Aspegren'),
('771022-3368','Ylva','Jacobsson'),
('730823-1807','Frida','Weidel'),
('730410-3281','Caroline','Olsson'),
('751203-1100','Karolin','Ek'),
('701113-2649','Eva','Hjort'),
('710210-1446','Sofia','Kjellberg'),
('731228-1541','Tina','Lööf'),
('800216-2249','Lisa','Berg'),
('770511-1685','Lotta','Bergman'),
('700405-3943','Susanne','Dahl'),
('700412-2680','Birgit','Ewesson'),
('790331-1343','Ulrika','Jonsson'),
('700303-1569','Jenny','Lundin'),
('730906-3902','Karin','Östberg'),
('771203-3252','Bo','Ek'),
('731019-2757','Bo','Ek'),
('741015-3311','Bo','Ek'),
('720710-3974','Erik','Andersson'),
('740726-1010','Erik','Andersson'),
('761001-1376','Filip','Gustavsson'),
('790710-1757','Niklas','Andersson'),
('741126-3275','David','Carlsson'),
('700818-2516','Tobias','Enberg'),
('711122-3678','Johan','Lind'),
('760304-2396','Magnus','Pettersson'),
('740602-1555','Filip','Persson'),
('790903-2919','Ola','Nilsson'),
('780328-1976','Jakob','Malmberg'),
('730119-2576','Henrik','Berg'),
('730917-2638','John','Lind'),
('800119-3294','Patrik','Lundh'),
('710706-2734','Mikael','Nilsson'),
('790504-1393','Joakim','Nilsson'),
('700222-3472','Conny','Modig'),
('801127-3276','Christian','Wallman'),
('790210-2412','Magnus','Strömgren'),
('710323-1051','Daniel','Ahlman'),
('740707-3571','Lars','Molin'),
('730226-3814','Magnus','Nilsson'),
('771103-2115','Anders','Olsson'),
('790513-1038','Martin','Alm'),
('720426-2898','Håkan','Mossgren'),
('700202-3633','Fredrik','Ryd'),
('720606-2932','Mats','Wikström'),
('710722-1553','Anders','Magnusson'),
('790911-2232','Andreas','Molin'),
('781202-2718','Johan','Brattberg'),
('760925-4011','Johan','Olsson'),
('720820-2999','Jonathan','Jansson'),
('710410-1154','Magnus','Hultgren'),
('790709-2311','Axel','Nord'),
('720801-2190','Henrik','Hult'),
('780531-2415','Joakim','Hall'),
('731216-1131','Henrik','Gustavsson'),
('700128-3170','Torbjörn','Modig'),
('720619-3737','Daniel','Axelsson'),
('800529-1250','Per-Erik','Pettersson'),
('750928-3557','Roger','Brorsson'),
('740310-3232','Patrik','Ohlsson'),
('790101-1234','Peter','Solberg');

-- Populate the Courses table.

insert into Courses values 
('EDA016','Programmering för D',5),
('EDA027','Algoritmer och datastrukturer',5),
('EDA250','Helhetsbild av datatekniken',6),
('ETI190','Elektronik',8),
('FMA410','Matematik, endimensionell analys',8),
('FMA420','Linjär algebra',4),
('FMA430','Flerdimensionell analys',4),
('EDA061','Objektorienterad modellering och design',3),
('EDA260','Programvaruutveckling i grupp - projekt',4),
('EIT020','Digitalteknik',6),
('EIT070','Datorteknik',4),
('ETS160','Metodik för programvaruutveckling',4),
('FAF106','Fysik, kurs för D',7),
('FMA030','Linjär analys för D',6),
('FMS022','Matematisk statistik AK',6),
('FMA035','Komplex och linjär analys',9),
('FMA091','Diskret matematik',4),
('EDA040','Realtidsprogrammering',4),
('ETS055','Datorkommunikation för D',6),
('FMN011','Numerisk analys för D',4),
('FRT010','Reglerteknik, AK',5),
('TEK210','Kognition',3),
('EDA050','Operativsystem',3),
('EDA055','Operativsystem med projekt',5),
('EDA120','Funktionsprogrammering',4),
('EDA180','Kompilatorteknik',5),
('EDA221','Datorgrafik',5),
('EEM023','Mätteknik',3),
('EIT060','Datasäkerhet',5),
('EIT080','Informationsteori',5),
('EIT090','Datorarkitektur',6),
('ETI031','Radio',4),
('ETI200','Konstruktion av system på kisel',3),
('ETI220','Integrerade A/D och D/A omvandlare',4),
('ETI275','Digital signalbehandling',4),
('ETS032','Programvaruutveckling för stora system',5),
('ETS120','Nätverksmodellering',6),
('FMA021','Kontinuerliga system',5),
('FMA110','Matematik FK, analysens grunder',4),
('FMA120','Matematik FK, matristeori',4),
('FMA121','Matematik FK, matristeori SK',6),
('FMA130','Matematik FK, analytiska funktioner',4),
('FMA135','Matematik FK, geometri',4),
('FMA190','Matematik FK, algebra',4),
('FMF090','Kaos inom naturvetenskap och teknik',4),
('FMF091','Kaos med projektarbete',6),
('FMI100','Teknisk miljövetenskap',5),
('FMN050','Numerisk analys för E',4),
('FMS045','Stationära stokastiska processer',4),
('FMS051','Matematisk statistik, tidsserieanalys',5),
('FMS180','Markovprocesser',4),
('FRT020','Digital reglering',5),
('MAM203','Arbete - människa - teknik, grundkurs',5),
('TNX170','Entreprenörskap och affärsutveckling',5),
('EEM022','Mät- och instrumenteringsteknik för E och D',5),
('ETS051','Datorkommunikation',4),
('AAM010','Miljöpsykologi',5),
('EDA045','Realtidsgrafik',4),
('EDA110','Algoritmteori',4),
('EDA132','Tillämpad artificiell intelligens',5),
('EDA145','Programspråksteori',5),
('EDA160','Kommunicerande processer',4),
('EDA170','Inledning till språkbehandling och datalingvistik',4),
('EDA215','Databaser',5),
('EDA230','Optimerande kompilatorer',5),
('EDA240','Konfigurationshantering',4),
('EDA331','Industrirelaterad programmering',3),
('EDA340','Constraint-programmering',4),
('EDA380','Konstruktion av inbyggda system',4),
('EDI021','Digitala projekt',5),
('EDI022','Digitala projekt, SK',8),
('EDI042','Kodningsteknik',5),
('EDI050','Kryptoteknik',4),
('EDI061','Datanät',4),
('EDT081','Datorsystemkonstruktion',5),
('EEM031','Sensorteknik',5),
('EEM050','Mikrosensorer',4),
('EEM060','EMC, störningar och störningsbegränsning',4),
('EEM070','Datorbaserade mätsystem',4),
('EIT010','Digitala transmissionsmetoder',5),
('EIT050','Digitala bilder - kompression',6),
('EIT120','Digitala strukturer på kisel',5),
('EIT130','VLSI-arkitektur',8),
('EIT140','Produktutveckling inom datorområdet',3),
('EIT150','Internet inuti',5),
('ETI120','Projekt i signalbehandling',4),
('ETI130','Digital IC-konstruktion',4),
('ETI160','Medicinsk signalbehandling',4),
('ETI180','DSP-design',4),
('ETI210','IC-projekt och verifiering',8),
('ETI270','Digital signalbehandling i audio/video',4),
('ETI280','Immaterialrätt',4),
('ETS040','Telekommunikation',4),
('ETS110','Internetprotokoll',5),
('ETT042','Adaptiv signalbehandling',4),
('ETT051','Digital kommunikation',5),
('ETT055','Digital kommunikation, FK',6),
('ETT062','Bandspridningsteknik',5),
('ETT074','Optimal signalbehandling',4),
('FAF111','Laserteknik',3),
('FAF141','Multispektral avbildning',4),
('FAF150','Medicinsk optik',5),
('FAF200','Strålningsfysik',5),
('FMA051','Optimering',4),
('FMA140','Matematik FK, olinjära dynamiska system',4),
('FMA141','Matematik FK, olinjära dynamiska system SK',6),
('FMA170','Matematik FK, bildanalys',4),
('FMA172','Matematik FK, bildanalys SK',6),
('FMA200','Matematik FK, variationskalkyl',4),
('FMA240','Matematik FK, linjär och kombinatorisk optimering',4),
('FMA250','Matematik FK, partiella differentialekvationer',5),
('FMA260','Matematik FK, funktionalanalys',5),
('FMA270','Matematik FK, datorseende',4),
('FMA271','Matematik FK, datorseende SK',6),
('FMN100','Numeriska metoder för datorgrafik',4),
('FMS072','Försöksplanering',5),
('FMS091','Monte Carlo-baserade statistiska metoder',5),
('FMS110','Olinjära tidsserier',5),
('FMS150','Statistisk bildanalys',5),
('FMS161','Finansiell statistik',5),
('FRT031','Realtidssystem',5),
('FRT041','Systemidentifiering',5),
('FRT050','Adaptiv reglering',5),
('FRT075','Olinjär reglering och servosystem',4),
('FRT100','Internationell projektkurs i reglerteknik',3),
('KII010','Industriellt milj�arbete',5),
('MAM026','Arbetsorganisation',3),
('MAM031','Arbete-människa-teknik, projekt',4),
('MAM060','Människa - datorinteraktion',5),
('MIE080','Automation',5),
('MIO012','Industriell ekonomi AK',4),
('MIO022','Företagsorganisation',5),
('TNX006','Medicin för tekniker',4),
('TNX011','Juridik för tekniker',5),
('TNX015','Svenska för tekniker',3),
('TNX020','Engelska för tekniker',5),
('TNX025','Tyska för tekniker',5),
('TNX031','Franska för tekniker I',5),
('TNX032','Franska för tekniker II',5),
('TNX035','Samhällsekonomi för tekniker',3),
('TNX040','Industriell marknadsföring och inköp',3),
('TNX097','Rehabiliteringsteknik',5),
('TNX153','Rehabiliteringsteknik och design',5),
('TNX180','Spanska för tekniker I',5),
('TNX185','Spanska för tekniker II',5),
('EDA135','Artificiell intelligens för robotar',5),
('EEM040','Medicinsk mätteknik',4),
('EEM080','Ultraljudsfysik och teknik',4),
('MIO040','Industriell ekonomi, FK',4);

-- Populate the TakenCourses table.

insert into TakenCourses values 
('710721-1927','EDA027',4),
('710721-1927','EIT070',3),
('710721-1927','FMS022',5),
('710721-1927','TEK210',5),
('710721-1927','EEM023',3),
('710721-1927','EIT060',5),
('710721-1927','ETI220',5),
('710721-1927','FMA110',3),
('710721-1927','FMA120',5),
('710721-1927','FMA130',3),
('710721-1927','FMI100',3),
('710721-1927','TNX170',4),
('710721-1927','EDA160',3),
('710721-1927','EDA240',5),
('710721-1927','EDI050',3),
('710721-1927','EEM031',3),
('710721-1927','ETI210',4),
('710721-1927','ETT074',4),
('710721-1927','FMA140',3),
('710721-1927','FMA141',5),
('710721-1927','FMA250',4),
('710721-1927','FRT041',5),
('710721-1927','MAM026',5),
('710721-1927','MAM031',4),
('710721-1927','MIO012',3),
('710721-1927','TNX006',5),
('710721-1927','TNX015',5),
('710721-1927','TNX097',4),
('710721-1927','EEM080',5),
('700627-2889','EDA250',5),
('700627-2889','FMA410',3),
('700627-2889','EDA260',3),
('700627-2889','FMA030',3),
('700627-2889','ETS055',4),
('700627-2889','EIT090',4),
('700627-2889','FMA110',4),
('700627-2889','FMA120',4),
('700627-2889','FMS045',4),
('700627-2889','FRT020',5),
('700627-2889','TNX170',5),
('700627-2889','EDA132',5),
('700627-2889','EDI021',3),
('700627-2889','EDI042',3),
('700627-2889','EDI050',5),
('700627-2889','EEM031',3),
('700627-2889','EEM060',4),
('700627-2889','EIT140',4),
('700627-2889','EIT150',3),
('700627-2889','ETT055',5),
('700627-2889','FAF111',5),
('700627-2889','FMA200',5),
('700627-2889','FMA240',3),
('700627-2889','FMA260',4),
('700627-2889','FMA271',5),
('700627-2889','FRT050',3),
('700627-2889','TNX032',3),
('700627-2889','TNX153',3),
('700627-2889','TNX180',4),
('700627-2889','EDA135',4),
('700627-2889','MIO040',4),
('730817-3900','FMA121',4),
('730817-3900','FMN050',5),
('730817-3900','EDA145',4),
('730817-3900','FAF200',3),
('730817-3900','TNX011',4),
('760213-3782','ETI190',3),
('760213-3782','ETS160',3),
('760213-3782','FAF106',4),
('760213-3782','EDA050',5),
('760213-3782','EDA120',5),
('760213-3782','EIT060',3),
('760213-3782','EIT080',5),
('760213-3782','ETI220',4),
('760213-3782','ETS032',4),
('760213-3782','ETS120',5),
('760213-3782','FMA121',5),
('760213-3782','EDA045',5),
('760213-3782','EDA160',5),
('760213-3782','EDA340',4),
('760213-3782','EDA380',5),
('760213-3782','EIT010',4),
('760213-3782','ETT062',5),
('760213-3782','FMA172',4),
('760213-3782','FMA250',3),
('760213-3782','FMS161',3),
('760213-3782','KII010',5),
('760213-3782','TNX153',4),
('760213-3782','TNX180',4),
('760213-3782','TNX185',3),
('780908-3285','FMA410',5),
('780908-3285','EIT090',5),
('780908-3285','ETS120',3),
('780908-3285','FMA110',3),
('780908-3285','FMA130',3),
('780908-3285','FRT020',3),
('780908-3285','MAM203',3),
('780908-3285','ETS051',5),
('780908-3285','EDA240',5),
('780908-3285','EDA331',3),
('780908-3285','EDA380',4),
('780908-3285','EDI022',3),
('780908-3285','EIT130',5),
('780908-3285','ETI280',4),
('780908-3285','ETS110',3),
('780908-3285','FMN100',5),
('780908-3285','FMS091',3),
('780908-3285','FMS110',4),
('780908-3285','TNX011',4),
('780908-3285','TNX180',3),
('780908-3285','EEM080',5),
('731108-2767','EDA016',3),
('731108-2767','FMA430',5),
('731108-2767','ETS160',5),
('731108-2767','EDA040',4),
('731108-2767','ETS055',4),
('731108-2767','TEK210',5),
('731108-2767','FMA121',3),
('731108-2767','FMF090',5),
('731108-2767','FMF091',3),
('731108-2767','ETS051',5),
('731108-2767','EDA145',4),
('731108-2767','EDA160',3),
('731108-2767','EDA230',4),
('731108-2767','EDA240',3),
('731108-2767','EDI050',5),
('731108-2767','EIT010',4),
('731108-2767','EIT130',4),
('731108-2767','FAF150',3),
('731108-2767','FMA170',5),
('731108-2767','FMA172',5),
('731108-2767','FRT075',5),
('731108-2767','KII010',4),
('731108-2767','MAM060',4),
('731108-2767','TNX011',5),
('731108-2767','TNX015',3),
('770806-2406','FMA030',4),
('770806-2406','FMS022',3),
('770806-2406','ETS055',5),
('770806-2406','FRT010',5),
('770806-2406','EDA180',3),
('770806-2406','EIT090',5),
('770806-2406','ETI220',3),
('770806-2406','ETI275',5),
('770806-2406','FMA135',3),
('770806-2406','FMA190',4),
('770806-2406','TNX170',4),
('770806-2406','EDA145',3),
('770806-2406','EDA240',3),
('770806-2406','EDI021',4),
('770806-2406','EDI042',4),
('770806-2406','EDI050',4),
('770806-2406','EDT081',3),
('770806-2406','EIT120',3),
('770806-2406','ETI130',5),
('770806-2406','ETT051',4),
('770806-2406','ETT074',5),
('770806-2406','FAF150',5),
('770806-2406','FMA140',4),
('770806-2406','FMA250',3),
('770806-2406','FMS161',5),
('770806-2406','FRT031',4),
('770806-2406','FRT041',4),
('770806-2406','KII010',5),
('770806-2406','MIO012',4),
('770806-2406','TNX006',5),
('730411-3207','EDA061',3),
('730411-3207','EIT020',5),
('730411-3207','FAF106',4),
('730411-3207','FMA091',5),
('730411-3207','FRT010',4),
('730411-3207','FMA110',3),
('730411-3207','FMA130',4),
('730411-3207','FMF091',5),
('730411-3207','FMS045',3),
('730411-3207','FMS180',4),
('730411-3207','TNX170',4),
('730411-3207','ETS051',4),
('730411-3207','EDA045',5),
('730411-3207','EDA110',5),
('730411-3207','EDA160',4),
('730411-3207','EDA331',4),
('730411-3207','EDA340',4),
('730411-3207','EDI042',4),
('730411-3207','EIT150',4),
('730411-3207','ETI270',5),
('730411-3207','ETI280',4),
('730411-3207','ETS040',5),
('730411-3207','ETS110',4),
('730411-3207','ETT042',5),
('730411-3207','ETT062',3),
('730411-3207','ETT074',5),
('730411-3207','FAF150',4),
('730411-3207','FMA051',4),
('730411-3207','FMA240',4),
('730411-3207','FMA270',4),
('730411-3207','FMS110',4),
('730411-3207','MIO022',3),
('730411-3207','TNX006',5),
('730411-3207','TNX011',3),
('730411-3207','TNX020',4),
('730411-3207','TNX032',5),
('730411-3207','TNX040',3),
('730411-3207','TNX180',3),
('730411-3207','EEM040',5),
('780404-2286','EDA027',4),
('780404-2286','EIT090',4),
('780404-2286','ETI220',3),
('780404-2286','ETI275',3),
('780404-2286','EDA170',4),
('780404-2286','EDI042',5),
('780404-2286','EEM070',3),
('780404-2286','ETI120',3),
('780404-2286','ETI130',4),
('780404-2286','ETI210',3),
('780404-2286','ETS110',5),
('780404-2286','FAF141',5),
('780404-2286','FMA170',4),
('780404-2286','FMA270',5),
('780404-2286','FMS161',5),
('780404-2286','FRT075',3),
('780404-2286','MAM026',4),
('780404-2286','MAM060',3),
('780404-2286','TNX015',5),
('780404-2286','TNX020',5),
('780404-2286','TNX035',3),
('780404-2286','TNX185',4),
('771022-3368','ETT074',5),
('730823-1807','FMA410',4),
('730823-1807','FMN011',3),
('730823-1807','EDA221',3),
('730823-1807','EIT080',3),
('730823-1807','FMF090',5),
('730823-1807','FMS051',5),
('730823-1807','EEM070',5),
('730823-1807','ETI120',4),
('730823-1807','ETI160',5),
('730823-1807','FAF141',4),
('730823-1807','FMA250',3),
('730823-1807','FMA270',3),
('730823-1807','FRT050',4),
('730823-1807','KII010',5),
('730823-1807','MIO022',5),
('730823-1807','TNX006',5),
('730823-1807','TNX015',5),
('730823-1807','TNX025',4),
('701113-2649','FMN011',4),
('701113-2649','EDA331',3),
('701113-2649','EDA340',5),
('701113-2649','FMA170',5),
('701113-2649','FMS161',3),
('701113-2649','MAM026',3),
('701113-2649','MIO022',3),
('710210-1446','FMA420',5),
('710210-1446','FMA430',3),
('710210-1446','EIT020',3),
('710210-1446','EIT070',3),
('710210-1446','ETS160',5),
('710210-1446','TEK210',5),
('710210-1446','EDA050',3),
('710210-1446','EDA055',4),
('710210-1446','EDA221',4),
('710210-1446','EEM023',4),
('710210-1446','ETI031',5),
('710210-1446','ETI200',5),
('710210-1446','ETS120',5),
('710210-1446','FMA021',4),
('710210-1446','FMA110',5),
('710210-1446','FMA120',5),
('710210-1446','FMF090',4),
('710210-1446','FMS051',4),
('710210-1446','MAM203',3),
('710210-1446','ETS051',3),
('710210-1446','EDA045',5),
('710210-1446','EDA132',4),
('710210-1446','EDA145',5),
('710210-1446','EDA240',3),
('710210-1446','EDA331',4),
('710210-1446','EDI022',3),
('710210-1446','EDI050',4),
('710210-1446','EEM031',5),
('710210-1446','EIT130',3),
('710210-1446','EIT140',4),
('710210-1446','ETI120',5),
('710210-1446','ETI160',5),
('710210-1446','ETI270',3),
('710210-1446','ETI280',3),
('710210-1446','ETT042',4),
('710210-1446','ETT062',4),
('710210-1446','ETT074',4),
('710210-1446','FAF111',4),
('710210-1446','FMA170',3),
('710210-1446','FMA200',4),
('710210-1446','FMA260',3),
('710210-1446','FMS110',4),
('710210-1446','FRT031',3),
('710210-1446','FRT100',5),
('710210-1446','KII010',3),
('710210-1446','MAM031',4),
('710210-1446','MIE080',3),
('710210-1446','TNX040',5),
('710210-1446','EEM080',5),
('710210-1446','MIO040',5),
('731228-1541','ETI190',3),
('731228-1541','FMA410',4),
('731228-1541','EDA120',4),
('731228-1541','EDA221',4),
('731228-1541','EEM023',4),
('731228-1541','FMA135',5),
('731228-1541','ETS051',4),
('731228-1541','EDA331',4),
('731228-1541','EDI022',3),
('731228-1541','EIT050',5),
('731228-1541','FAF200',4),
('731228-1541','FMA051',5),
('731228-1541','FMS091',4),
('731228-1541','MAM060',4),
('731228-1541','TNX097',5),
('800216-2249','EDA027',3),
('800216-2249','ETI190',3),
('800216-2249','ETS160',3),
('800216-2249','EDA040',5),
('800216-2249','ETS055',3),
('800216-2249','EDA050',3),
('800216-2249','EDA055',4),
('800216-2249','EDA120',4),
('800216-2249','ETS051',3),
('800216-2249','EDA110',5),
('800216-2249','EDA215',4),
('800216-2249','EDI050',3),
('800216-2249','EDI061',3),
('800216-2249','EIT050',3),
('800216-2249','EIT140',5),
('800216-2249','ETT042',5),
('800216-2249','FAF200',5),
('800216-2249','FMA051',4),
('800216-2249','FMA172',3),
('800216-2249','FRT075',5),
('800216-2249','TNX006',3),
('800216-2249','TNX015',3),
('800216-2249','TNX040',4),
('800216-2249','TNX097',3),
('800216-2249','TNX185',4),
('770511-1685','EDA061',3),
('770511-1685','EDA221',4),
('770511-1685','FMA021',4),
('770511-1685','FMF090',4),
('770511-1685','MAM203',5),
('770511-1685','EEM060',3),
('770511-1685','MAM060',5),
('700405-3943','FMA430',5),
('700405-3943','EDA221',3),
('700405-3943','EIT090',4),
('700405-3943','FMA021',3),
('700405-3943','FMF091',4),
('700405-3943','FRT020',3),
('700405-3943','EDA110',5),
('700405-3943','FMS091',5),
('700405-3943','FRT031',5),
('700405-3943','MIO012',5),
('700405-3943','TNX025',5),
('700405-3943','TNX040',5),
('700412-2680','FMA035',5),
('700412-2680','FMA091',3),
('700412-2680','EDA040',4),
('700412-2680','FMA021',5),
('700412-2680','EDA160',3),
('700412-2680','EDA240',5),
('700412-2680','MAM026',4),
('700412-2680','TNX032',4),
('790331-1343','EDA055',4),
('790331-1343','EDA120',3),
('790331-1343','EDA221',4),
('790331-1343','FMF091',5),
('790331-1343','TNX170',3),
('790331-1343','EDA045',5),
('790331-1343','EEM050',5),
('790331-1343','EIT130',3),
('790331-1343','ETI130',3),
('790331-1343','FAF150',3),
('790331-1343','FMS072',4),
('790331-1343','FRT050',5),
('790331-1343','TNX011',4),
('790331-1343','TNX097',3),
('790331-1343','TNX153',5),
('730906-3902','FMA091',4),
('730906-3902','FMA110',4),
('730906-3902','FMA121',4),
('730906-3902','FMS045',4),
('730906-3902','EEM022',5),
('730906-3902','ETI130',4),
('730906-3902','ETT042',4),
('730906-3902','ETT051',4),
('730906-3902','ETT062',3),
('730906-3902','FMA051',5),
('730906-3902','FMA140',4),
('730906-3902','FMA141',4),
('730906-3902','FMA260',5),
('730906-3902','FMS110',5),
('730906-3902','TNX011',4),
('730906-3902','TNX185',3),
('731019-2757','FMS180',3),
('741015-3311','ETI190',5),
('741015-3311','EDA180',3),
('741015-3311','ETI220',3),
('741015-3311','ETS120',5),
('741015-3311','EDA230',4),
('741015-3311','EDT081',3),
('741015-3311','FMS161',4),
('741015-3311','KII010',4),
('741015-3311','TNX011',4),
('741015-3311','TNX040',5),
('741015-3311','TNX180',4),
('720710-3974','FMA030',5),
('720710-3974','EDA055',5),
('720710-3974','EEM023',3),
('720710-3974','ETI275',4),
('720710-3974','FMA110',5),
('720710-3974','FMA120',4),
('720710-3974','FMA130',3),
('720710-3974','EDA110',4),
('720710-3974','EDA132',4),
('720710-3974','EDA145',5),
('720710-3974','EDT081',5),
('720710-3974','EIT050',3),
('720710-3974','ETI120',4),
('720710-3974','ETI210',4),
('720710-3974','ETS110',5),
('720710-3974','ETT051',4),
('720710-3974','FMA170',3),
('720710-3974','FMA270',4),
('720710-3974','FMS072',5),
('720710-3974','FRT075',4),
('720710-3974','TNX031',5),
('720710-3974','TNX032',4),
('740726-1010','EDA016',5),
('740726-1010','ETI190',4),
('740726-1010','EDA061',4),
('740726-1010','ETS055',4),
('740726-1010','TEK210',3),
('740726-1010','EDA120',3),
('740726-1010','EDA180',4),
('740726-1010','EDA221',4),
('740726-1010','ETS120',5),
('740726-1010','FMA021',3),
('740726-1010','FMF090',5),
('740726-1010','FMI100',5),
('740726-1010','FMN050',3),
('740726-1010','FMS045',3),
('740726-1010','ETS051',4),
('740726-1010','EDA240',4),
('740726-1010','EDI042',5),
('740726-1010','EDI061',4),
('740726-1010','EEM031',3),
('740726-1010','EEM050',3),
('740726-1010','EEM070',5),
('740726-1010','EIT140',4),
('740726-1010','ETI120',3),
('740726-1010','ETI160',3),
('740726-1010','ETI180',3),
('740726-1010','ETI210',3),
('740726-1010','ETS040',3),
('740726-1010','ETT051',3),
('740726-1010','FAF111',3),
('740726-1010','FMA051',5),
('740726-1010','FMA140',3),
('740726-1010','FMA172',5),
('740726-1010','FMA200',5),
('740726-1010','FMA270',5),
('740726-1010','FMS150',4),
('740726-1010','FMS161',3),
('740726-1010','TNX011',4),
('740726-1010','TNX020',5),
('740726-1010','TNX153',5),
('740726-1010','EDA135',3),
('761001-1376','FMA430',3),
('761001-1376','FMS022',3),
('761001-1376','FRT010',4),
('761001-1376','EIT080',4),
('761001-1376','ETI031',4),
('761001-1376','ETI220',5),
('761001-1376','FMA135',4),
('761001-1376','FMS180',5),
('761001-1376','FRT020',3),
('761001-1376','TNX170',5),
('761001-1376','EIT050',3),
('761001-1376','EIT120',4),
('761001-1376','ETI130',4),
('761001-1376','ETI160',4),
('761001-1376','ETI270',4),
('761001-1376','ETT055',3),
('761001-1376','ETT062',3),
('761001-1376','ETT074',4),
('761001-1376','FMA140',3),
('761001-1376','FMA172',3),
('761001-1376','FMA270',3),
('761001-1376','FMS150',5),
('761001-1376','FRT041',3),
('761001-1376','MAM060',3),
('761001-1376','TNX031',5),
('761001-1376','TNX035',4),
('761001-1376','EEM080',4),
('790710-1757','FMA430',4),
('790710-1757','FMN011',5),
('790710-1757','EIT080',5),
('790710-1757','FRT100',4),
('790710-1757','TNX035',4),
('741126-3275','EDA260',5),
('741126-3275','FAF106',5),
('741126-3275','FMS022',5),
('741126-3275','EDA055',3),
('741126-3275','EDA180',4),
('741126-3275','EIT080',3),
('741126-3275','FMS051',4),
('741126-3275','EEM022',4),
('741126-3275','EDA331',4),
('741126-3275','EEM070',4),
('741126-3275','EIT010',4),
('741126-3275','EIT120',5),
('741126-3275','ETT055',3),
('741126-3275','ETT062',5),
('741126-3275','FAF200',4),
('741126-3275','FMA240',4),
('741126-3275','FMS161',4),
('741126-3275','FRT075',3),
('741126-3275','MAM031',5),
('741126-3275','MIO022',4),
('741126-3275','TNX006',4),
('741126-3275','TNX020',4),
('741126-3275','TNX032',4),
('741126-3275','TNX180',4),
('741126-3275','EDA135',4),
('700818-2516','FMA035',5),
('700818-2516','FMS045',4),
('700818-2516','ETI160',4),
('700818-2516','ETS040',3),
('700818-2516','FAF200',4),
('700818-2516','FMA172',4),
('700818-2516','FMS072',3),
('700818-2516','FMS110',3),
('700818-2516','FRT031',3),
('700818-2516','FRT050',4),
('700818-2516','MIE080',5),
('711122-3678','FMA190',4),
('711122-3678','FMS180',4),
('711122-3678','EDA160',3),
('711122-3678','EDA331',5),
('711122-3678','ETI180',5),
('711122-3678','ETS110',5),
('711122-3678','TNX025',3),
('760304-2396','ETI190',5),
('760304-2396','FMA091',5),
('760304-2396','EDA040',5),
('760304-2396','EDA221',3),
('760304-2396','EIT060',3),
('760304-2396','FMA135',4),
('760304-2396','EDA045',4),
('760304-2396','ETI160',4),
('760304-2396','ETT051',4),
('760304-2396','ETT055',3),
('760304-2396','ETT062',4),
('760304-2396','FMA240',5),
('760304-2396','FMA260',3),
('760304-2396','FRT031',3),
('760304-2396','TNX025',3),
('760304-2396','EEM040',5),
('760304-2396','EEM080',4),
('740602-1555','FMA410',4),
('740602-1555','EDA260',5),
('740602-1555','FMS022',5),
('740602-1555','ETS055',3),
('740602-1555','EDA120',5),
('740602-1555','ETI200',3),
('740602-1555','ETS120',3),
('740602-1555','FMS051',4),
('740602-1555','EDA132',5),
('740602-1555','EDA215',5),
('740602-1555','EDA240',5),
('740602-1555','EDA340',4),
('740602-1555','EDI042',3),
('740602-1555','EDT081',4),
('740602-1555','EIT140',3),
('740602-1555','ETI180',4),
('740602-1555','FMA270',4),
('740602-1555','FRT075',4),
('740602-1555','MAM060',5),
('740602-1555','MIO022',4),
('740602-1555','TNX006',5),
('740602-1555','TNX020',5),
('740602-1555','EEM040',3),
('730119-2576','EDA250',5),
('730119-2576','FMA430',5),
('730119-2576','ETI275',5),
('730119-2576','FMA110',4),
('730119-2576','FMA121',5),
('730119-2576','FMF090',5),
('730119-2576','TNX170',4),
('730119-2576','EDA240',5),
('730119-2576','EDI042',4),
('730119-2576','EIT140',3),
('730119-2576','ETI160',3),
('730119-2576','ETS040',5),
('730119-2576','ETS110',5),
('730119-2576','ETT055',5),
('730119-2576','ETT074',3),
('730119-2576','FMA140',5),
('730119-2576','FMS150',4),
('730119-2576','FRT075',4),
('730119-2576','KII010',3),
('730119-2576','MAM031',4),
('730119-2576','TNX015',4),
('730119-2576','TNX035',4),
('730119-2576','TNX180',3),
('730119-2576','EEM080',3),
('730917-2638','EEM031',5),
('800119-3294','ETS055',3),
('800119-3294','EDA120',4),
('800119-3294','EDA221',5),
('800119-3294','ETI200',5),
('800119-3294','FMF090',5),
('800119-3294','FMS051',4),
('800119-3294','EEM022',5),
('800119-3294','EDA215',4),
('800119-3294','EDT081',4),
('800119-3294','ETI160',4),
('800119-3294','FMA260',4),
('800119-3294','FRT050',4),
('800119-3294','MAM060',5),
('800119-3294','TNX006',5),
('800119-3294','MIO040',4),
('710706-2734','EDA016',4),
('710706-2734','FMA030',3),
('710706-2734','FMA091',4),
('710706-2734','EDA050',5),
('710706-2734','EDA055',4),
('710706-2734','FMA121',5),
('710706-2734','FMA130',3),
('710706-2734','FMA190',4),
('710706-2734','TNX170',5),
('710706-2734','EDA170',4),
('710706-2734','EEM031',4),
('710706-2734','ETI270',5),
('710706-2734','ETT051',5),
('710706-2734','FMS110',5),
('710706-2734','FMS161',4),
('710706-2734','FRT041',3),
('710706-2734','FRT100',5),
('710706-2734','MAM026',5),
('710706-2734','TNX032',5),
('710706-2734','TNX097',3),
('710706-2734','TNX185',4),
('790504-1393','EDA250',3),
('790504-1393','EIT070',4),
('790504-1393','FAF106',4),
('790504-1393','EDA040',3),
('790504-1393','ETS055',4),
('790504-1393','EDA055',4),
('790504-1393','MAM203',3),
('790504-1393','ETS051',3),
('790504-1393','EDA110',4),
('790504-1393','EIT050',5),
('790504-1393','ETI270',4),
('790504-1393','FMA051',3),
('790504-1393','FMA200',5),
('790504-1393','FMA240',5),
('790504-1393','FMA270',5),
('790504-1393','FMN100',3),
('790504-1393','FRT031',3),
('790504-1393','MAM060',5),
('790504-1393','TNX006',3),
('790504-1393','TNX031',3),
('790504-1393','TNX035',5),
('700222-3472','ETI190',4),
('700222-3472','EDA260',5),
('700222-3472','EIT020',3),
('700222-3472','FMA030',5),
('700222-3472','ETS055',4),
('700222-3472','FRT010',5),
('700222-3472','EDA120',3),
('700222-3472','EIT060',4),
('700222-3472','EIT080',5),
('700222-3472','ETI031',5),
('700222-3472','ETI275',5),
('700222-3472','ETS120',3),
('700222-3472','FMA130',3),
('700222-3472','FMS180',4),
('700222-3472','EDA160',3),
('700222-3472','EDA331',5),
('700222-3472','EDI022',5),
('700222-3472','EDI050',4),
('700222-3472','EEM031',4),
('700222-3472','EEM050',4),
('700222-3472','EIT120',4),
('700222-3472','ETS040',4),
('700222-3472','FAF111',5),
('700222-3472','FAF150',4),
('700222-3472','FMA170',3),
('700222-3472','FMA172',4),
('700222-3472','FMA200',5),
('700222-3472','FMA260',4),
('700222-3472','FMN100',5),
('700222-3472','FMS110',5),
('700222-3472','FMS161',3),
('700222-3472','FRT031',5),
('700222-3472','FRT075',4),
('700222-3472','MAM060',5),
('700222-3472','TNX011',4),
('700222-3472','TNX032',3),
('700222-3472','TNX180',3),
('700222-3472','EEM040',5),
('700222-3472','MIO040',3),
('801127-3276','FMA030',3),
('801127-3276','EDA050',3),
('801127-3276','EDA180',4),
('801127-3276','EIT060',3),
('801127-3276','FMA135',5),
('801127-3276','FMS045',4),
('801127-3276','ETS051',5),
('801127-3276','AAM010',5),
('801127-3276','EDA240',4),
('801127-3276','EDA380',3),
('801127-3276','EDI042',3),
('801127-3276','EDI050',5),
('801127-3276','EDI061',3),
('801127-3276','EDT081',5),
('801127-3276','EEM050',3),
('801127-3276','EEM070',5),
('801127-3276','ETI120',3),
('801127-3276','ETI280',5),
('801127-3276','ETS110',3),
('801127-3276','ETT074',5),
('801127-3276','FAF150',5),
('801127-3276','FMA170',4),
('801127-3276','FMN100',3),
('801127-3276','FMS161',3),
('801127-3276','FRT031',4),
('801127-3276','MAM060',3),
('801127-3276','TNX015',5),
('801127-3276','TNX020',5),
('801127-3276','TNX097',4),
('801127-3276','EEM080',3),
('790210-2412','FMA035',3),
('790210-2412','FRT010',5),
('790210-2412','EDA120',3),
('790210-2412','EIT090',5),
('790210-2412','FMF090',5),
('790210-2412','EDA132',4),
('790210-2412','EDA160',4),
('790210-2412','EDI050',3),
('790210-2412','EEM050',4),
('790210-2412','ETI160',4),
('790210-2412','ETT074',4),
('790210-2412','FMA172',3),
('790210-2412','FMA271',3),
('790210-2412','MAM026',5),
('790210-2412','TNX011',3),
('790210-2412','TNX020',3),
('790210-2412','TNX040',5),
('790210-2412','TNX185',5),
('710323-1051','FAF106',4),
('710323-1051','FMA035',4),
('710323-1051','EDA055',4),
('710323-1051','EDA221',4),
('710323-1051','EIT080',3),
('710323-1051','FMA190',4),
('710323-1051','ETI270',5),
('710323-1051','MAM031',5),
('710323-1051','TNX020',5),
('710323-1051','EEM080',3),
('740707-3571','ETI190',5),
('740707-3571','FMA410',4),
('740707-3571','FMA420',3),
('740707-3571','EDA061',3),
('740707-3571','FMA030',3),
('740707-3571','FMA091',4),
('740707-3571','EDA055',3),
('740707-3571','EEM023',5),
('740707-3571','EIT090',3),
('740707-3571','FMA135',5),
('740707-3571','FMF090',4),
('740707-3571','MAM203',3),
('740707-3571','AAM010',4),
('740707-3571','EDA215',3),
('740707-3571','EEM031',5),
('740707-3571','ETT042',5),
('740707-3571','FMA200',5),
('740707-3571','FRT031',5),
('740707-3571','TNX015',3),
('740707-3571','TNX035',3),
('740707-3571','TNX097',3),
('740707-3571','TNX153',3),
('730226-3814','FMA420',5),
('730226-3814','EDA260',5),
('730226-3814','EIT020',3),
('730226-3814','FMA035',3),
('730226-3814','FMA091',5),
('730226-3814','EDA040',5),
('730226-3814','EIT080',4),
('730226-3814','ETS032',5),
('730226-3814','ETS120',3),
('730226-3814','FMA110',3),
('730226-3814','FMF091',4),
('730226-3814','FMI100',5),
('730226-3814','FMN050',3),
('730226-3814','FRT020',5),
('730226-3814','EDA145',5),
('730226-3814','EDA170',4),
('730226-3814','EDA215',5),
('730226-3814','EDI022',5),
('730226-3814','EDI061',5),
('730226-3814','EEM060',4),
('730226-3814','EEM070',3),
('730226-3814','EIT130',4),
('730226-3814','ETI130',3),
('730226-3814','ETI160',4),
('730226-3814','ETS040',3),
('730226-3814','ETT055',3),
('730226-3814','FAF200',5),
('730226-3814','FMA250',4),
('730226-3814','FMA270',3),
('730226-3814','FMS072',3),
('730226-3814','FRT041',3),
('730226-3814','MIO022',5),
('730226-3814','TNX011',5),
('730226-3814','TNX015',5),
('730226-3814','TNX035',4),
('730226-3814','EEM080',5),
('771103-2115','FMA420',3),
('771103-2115','EDA061',5),
('771103-2115','EDA040',4),
('771103-2115','ETS055',3),
('771103-2115','FMA121',5),
('771103-2115','FMA130',3),
('771103-2115','FRT020',3),
('771103-2115','ETI270',5),
('771103-2115','ETI280',3),
('771103-2115','ETT051',5),
('771103-2115','FAF141',3),
('771103-2115','TNX011',3),
('771103-2115','TNX097',3),
('771103-2115','EDA135',3),
('790513-1038','EDA250',3),
('790513-1038','ETI190',3),
('790513-1038','EIT020',5),
('790513-1038','FMS022',5),
('790513-1038','FMA091',5),
('790513-1038','EDA040',4),
('790513-1038','FRT010',4),
('790513-1038','EDA120',5),
('790513-1038','EIT060',5),
('790513-1038','EIT090',3),
('790513-1038','ETS120',4),
('790513-1038','FMA120',4),
('790513-1038','FMF090',5),
('790513-1038','EEM022',4),
('790513-1038','AAM010',5),
('790513-1038','EDA170',4),
('790513-1038','EDA215',4),
('790513-1038','EDI022',5),
('790513-1038','EDI042',3),
('790513-1038','EDI061',3),
('790513-1038','ETI280',5),
('790513-1038','ETS040',4),
('790513-1038','ETS110',3),
('790513-1038','ETT074',5),
('790513-1038','FAF111',4),
('790513-1038','FAF150',5),
('790513-1038','FMA140',4),
('790513-1038','FMA240',5),
('790513-1038','FMA270',4),
('790513-1038','FRT041',3),
('790513-1038','EEM040',4),
('790513-1038','MIO040',5),
('720426-2898','EDA016',4),
('720426-2898','EDA260',3),
('720426-2898','EEM023',3),
('720426-2898','MAM203',3),
('720426-2898','EDI061',4),
('720426-2898','EEM060',4),
('720426-2898','ETS040',4),
('720426-2898','FRT031',5),
('720426-2898','FRT041',3),
('720426-2898','TNX097',3),
('700202-3633','FAF106',5),
('700202-3633','EDA180',5),
('700202-3633','EIT080',3),
('700202-3633','EIT090',4),
('700202-3633','ETI275',5),
('700202-3633','ETS032',5),
('700202-3633','ETS120',3),
('700202-3633','FMA130',5),
('700202-3633','FMF090',4),
('700202-3633','FMI100',5),
('700202-3633','FMN050',3),
('700202-3633','EDA380',5),
('700202-3633','EDT081',3),
('700202-3633','EIT050',5),
('700202-3633','ETI130',4),
('700202-3633','ETT051',5),
('700202-3633','ETT062',3),
('700202-3633','FMA170',4),
('700202-3633','FRT100',3),
('700202-3633','MIE080',4),
('700202-3633','TNX015',3),
('700202-3633','TNX031',4),
('700202-3633','MIO040',4),
('720606-2932','MAM203',5),
('720606-2932','EDA145',4),
('720606-2932','EDI050',4),
('720606-2932','FAF111',3),
('720606-2932','MAM031',5),
('720606-2932','TNX153',4),
('710722-1553','ETS160',5),
('710722-1553','FMA030',5),
('710722-1553','FRT010',3),
('710722-1553','ETI200',5),
('710722-1553','EDA340',5),
('710722-1553','ETS040',5),
('710722-1553','FMA141',4),
('710722-1553','FMA270',4),
('710722-1553','KII010',3),
('790911-2232','EIT080',4),
('790911-2232','EDA110',3),
('790911-2232','MAM031',5),
('790911-2232','MAM060',4),
('790911-2232','MIE080',5),
('720820-2999','EDA016',3),
('720820-2999','EDA027',4),
('720820-2999','FMA430',3),
('720820-2999','EIT020',4),
('720820-2999','FAF106',3),
('720820-2999','ETS055',5),
('720820-2999','EDA055',5),
('720820-2999','EDA180',3),
('720820-2999','EEM023',4),
('720820-2999','ETI200',5),
('720820-2999','ETS120',3),
('720820-2999','FMA110',3),
('720820-2999','FMA130',3),
('720820-2999','FMA190',4),
('720820-2999','FMI100',3),
('720820-2999','FRT020',3),
('720820-2999','EEM022',4),
('720820-2999','EDA160',3),
('720820-2999','EDA331',3),
('720820-2999','EDA380',5),
('720820-2999','EDI050',5),
('720820-2999','EEM060',4),
('720820-2999','EIT130',4),
('720820-2999','EIT150',4),
('720820-2999','ETI160',3),
('720820-2999','ETS110',4),
('720820-2999','FAF111',3),
('720820-2999','FMA051',5),
('720820-2999','FMA200',5),
('720820-2999','FMA260',3),
('720820-2999','FMS072',4),
('720820-2999','FMS091',3),
('720820-2999','FRT031',3),
('720820-2999','MIE080',3),
('720820-2999','TNX006',5),
('720820-2999','TNX011',5),
('720820-2999','TNX020',5),
('720820-2999','TNX031',4),
('720820-2999','TNX040',3),
('720820-2999','TNX153',4),
('720820-2999','TNX185',3),
('720820-2999','EEM040',3),
('710410-1154','ETI190',4),
('710410-1154','FMA410',5),
('710410-1154','FMA420',5),
('710410-1154','FMA430',5),
('710410-1154','EDA260',3),
('710410-1154','ETS160',4),
('710410-1154','FMS022',5),
('710410-1154','FMA091',3),
('710410-1154','EDA040',3),
('710410-1154','EDA221',3),
('710410-1154','ETS032',5),
('710410-1154','FMF090',4),
('710410-1154','FMS180',5),
('710410-1154','ETS051',5),
('710410-1154','AAM010',4),
('710410-1154','EDA110',4),
('710410-1154','EDA331',3),
('710410-1154','EDA340',4),
('710410-1154','EDI042',5),
('710410-1154','EIT120',3),
('710410-1154','EIT140',5),
('710410-1154','EIT150',5),
('710410-1154','ETI130',4),
('710410-1154','ETI270',5),
('710410-1154','ETS040',5),
('710410-1154','ETT074',5),
('710410-1154','FAF111',4),
('710410-1154','FAF150',4),
('710410-1154','FMA051',3),
('710410-1154','FMA141',4),
('710410-1154','FMA172',3),
('710410-1154','FMA271',4),
('710410-1154','FMN100',4),
('710410-1154','FMS091',3),
('710410-1154','FRT031',4),
('710410-1154','MAM031',4),
('710410-1154','TNX020',4),
('790709-2311','EIT020',4),
('790709-2311','ETS160',4),
('790709-2311','EDA040',4),
('790709-2311','EIT060',4),
('790709-2311','ETI275',4),
('790709-2311','FMA021',3),
('790709-2311','FMA121',4),
('790709-2311','FMF091',3),
('790709-2311','FMS180',5),
('790709-2311','TNX170',4),
('790709-2311','AAM010',3),
('790709-2311','EDA045',5),
('790709-2311','EDA230',5),
('790709-2311','EEM050',3),
('790709-2311','FAF141',4),
('790709-2311','FAF200',3),
('790709-2311','FMA270',5),
('790709-2311','FRT075',3),
('790709-2311','TNX185',3),
('790709-2311','EDA135',5),
('720801-2190','EDA016',5),
('720801-2190','FMA410',4),
('720801-2190','EIT020',5),
('720801-2190','FMS022',3),
('720801-2190','FMA035',4),
('720801-2190','EEM023',4),
('720801-2190','FMA120',5),
('720801-2190','FMS051',5),
('720801-2190','FMS180',5),
('720801-2190','EDA215',4),
('720801-2190','EDA240',5),
('720801-2190','EDA340',3),
('720801-2190','EEM050',5),
('720801-2190','EIT050',3),
('720801-2190','EIT140',5),
('720801-2190','ETI120',5),
('720801-2190','ETI130',5),
('720801-2190','ETI280',4),
('720801-2190','ETT062',5),
('720801-2190','FAF150',3),
('720801-2190','FMA140',3),
('720801-2190','FMA172',4),
('720801-2190','FMA240',4),
('720801-2190','FMS091',5),
('720801-2190','FRT031',4),
('720801-2190','MAM031',5),
('720801-2190','MIE080',4),
('720801-2190','MIO012',3),
('720801-2190','TNX040',4),
('720801-2190','TNX097',5),
('720801-2190','TNX180',4),
('780531-2415','FMA091',3),
('780531-2415','EDA221',5),
('780531-2415','FMA121',3),
('780531-2415','EDA230',5),
('780531-2415','EDI022',3),
('780531-2415','EDT081',3),
('780531-2415','ETI130',5),
('780531-2415','MAM060',4),
('720619-3737','EDA027',5),
('720619-3737','ETI190',5),
('720619-3737','EDA260',4),
('720619-3737','ETS160',5),
('720619-3737','FAF106',3),
('720619-3737','FMA030',4),
('720619-3737','FMS022',4),
('720619-3737','FMA091',3),
('720619-3737','ETS055',4),
('720619-3737','FRT010',4),
('720619-3737','EEM023',3),
('720619-3737','EIT060',4),
('720619-3737','ETI200',3),
('720619-3737','ETI220',5),
('720619-3737','FMF091',4),
('720619-3737','FMS045',4),
('720619-3737','ETS051',5),
('720619-3737','EDA045',4),
('720619-3737','EDI042',5),
('720619-3737','EEM031',4),
('720619-3737','EEM050',3),
('720619-3737','EIT150',4),
('720619-3737','ETI180',4),
('720619-3737','ETI270',3),
('720619-3737','ETT051',4),
('720619-3737','ETT055',4),
('720619-3737','FAF111',5),
('720619-3737','FAF150',4),
('720619-3737','FMS072',4),
('720619-3737','MAM060',5),
('720619-3737','MIO022',4),
('720619-3737','TNX011',3),
('720619-3737','TNX153',4),
('720619-3737','EEM080',4),
('790101-1234','FMA091',4),
('790101-1234','ETS055',5),
('790101-1234','FRT010',4),
('790101-1234','FMA135',5),
('790101-1234','FMS180',4),
('790101-1234','FMA260',3),
('790101-1234','FRT041',5);

-- Commit the transaction.

commit;

-- And re-enable foreign key checks.

PRAGMA foreign_keys = ON;

